==> apache-seata-2.1.0-incubating-src.tar.gz: apache-seata-2.1.0-incubating-src/server/src/main/java/org/apache/seata/server/coordinator/Core.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.coordinator;

import org.apache.seata.core.exception.TransactionException;
import org.apache.seata.core.model.GlobalStatus;
import org.apache.seata.server.session.GlobalSession;

/**
 * The interface Core.
 *
 */
public interface Core extends TransactionCoordinatorInbound, TransactionCoordinatorOutbound {

    /**
     * Do global commit.
     *
     * @param globalSession the global session
     * @param retrying      the retrying
     * @return is global commit.
     * @throws TransactionException the transaction exception
     */
    boolean doGlobalCommit(GlobalSession globalSession, boolean retrying) throws TransactionException;

    /**
     * Do global rollback.
     *
     * @param globalSession the global session
     * @param retrying      the retrying
     * @return is global rollback.
     * @throws TransactionException the transaction exception
     */
    boolean doGlobalRollback(GlobalSession globalSession, boolean retrying) throws TransactionException;

    /**
     * Do global report.
     *
     * @param globalSession the global session
     * @param xid           Transaction id.
     * @param param         the global status
     * @throws TransactionException the transaction exception
     */
    void doGlobalReport(GlobalSession globalSession, String xid, GlobalStatus param) throws TransactionException;

}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/server/src/main/java/org/apache/seata/server/coordinator/Core.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.coordinator;

import org.apache.seata.core.exception.TransactionException;
import org.apache.seata.core.model.GlobalStatus;
import org.apache.seata.server.session.BranchSession;
import org.apache.seata.server.session.GlobalSession;

/**
 * The interface Core.
 *
 */
public interface Core extends TransactionCoordinatorInbound, TransactionCoordinatorOutbound {

    /**
     * Do global commit.
     *
     * @param globalSession the global session
     * @param retrying      the retrying
     * @return is global commit.
     * @throws TransactionException the transaction exception
     */
    boolean doGlobalCommit(GlobalSession globalSession, boolean retrying) throws TransactionException;

    /**
     * Do global rollback.
     *
     * @param globalSession the global session
     * @param retrying      the retrying
     * @return is global rollback.
     * @throws TransactionException the transaction exception
     */
    boolean doGlobalRollback(GlobalSession globalSession, boolean retrying) throws TransactionException;

    /**
     * Do global report.
     *
     * @param globalSession the global session
     * @param xid           Transaction id.
     * @param param         the global status
     * @throws TransactionException the transaction exception
     */
    void doGlobalReport(GlobalSession globalSession, String xid, GlobalStatus param) throws TransactionException;

    /**
     * Do branch delete.
     *
     * @param globalSession the global session
     * @param branchSession the branch session
     * @throws TransactionException the transaction exception
     */
    Boolean doBranchDelete(GlobalSession globalSession, BranchSession branchSession) throws TransactionException;
}
